import { A as r, B as u } from "./api-client-ak_qxkXZ.js";
class m extends r {
  /**
   * Constructs a new instance of the AppAutomateClient class.
   * @param options - Optional configuration options for the client.
   */
  constructor(e) {
    super({
      ...e,
      baseUrl: (e == null ? void 0 : e.baseUrl) ?? "https://api.browserstack.com"
    });
  }
  /**
   * Retrieves the plan information for App Automate.
   * @param options - The fetch options for the request.
   * @returns A promise that resolves with the plan information.
   */
  getPlan(e) {
    return this.makeGetRequest("/app-automate/plan.json", e);
  }
  /**
   * Retrieves the list of devices available for App Automate.
   * @param options - The fetch options for the request.
   * @returns A promise that resolves with the list of devices.
   */
  getDevices(e) {
    return this.makeGetRequest("/app-automate/devices.json", e);
  }
  /**
   * Retrieves the projects from the App Automate API.
   * @param options - The fetch options for the API request.
   * @returns A promise that resolves with the projects.
   */
  getProjects(e) {
    return this.makeGetRequest("/app-automate/projects.json", e);
  }
  /**
   * Retrieves a project by its ID.
   * @param projectId The ID of the project to retrieve.
   * @param options Additional options for the fetch request.
   * @returns A promise that resolves to the retrieved project.
   */
  getProject(e, t) {
    return this.makeGetRequest("/app-automate/projects/{projectId}.json", {
      ...t,
      params: {
        path: {
          projectId: e
        }
      }
    }).then((a) => a.project);
  }
  /**
   * Updates a project in the App Automate API.
   *
   * @param projectId - The ID of the project to update.
   * @param body - The request body containing the updated project data.
   * @param options - Additional options for the request.
   * @returns A promise that resolves with the updated project data.
   */
  updateProject(e, t, a) {
    return this.makePutRequest("/app-automate/projects/{projectId}.json", {
      ...a,
      params: {
        path: {
          projectId: e
        }
      },
      body: t
    });
  }
  /**
   * Deletes a project.
   * @param projectId The ID of the project to delete.
   * @param options The fetch options for the delete request.
   * @returns A promise that resolves when the project is successfully deleted.
   */
  deleteProject(e, t) {
    return this.makeDeleteRequest("/app-automate/projects/{projectId}.json", {
      ...t,
      params: {
        path: {
          projectId: e
        }
      }
    });
  }
  /**
   * Retrieves the badge key for a specific project.
   * @param projectId The ID of the project.
   * @param options Additional options for the fetch request.
   * @returns A promise that resolves to the badge key.
   */
  getBadgeKey(e, t) {
    return this.makeGetRequest("/app-automate/projects/{projectId}/badge_key", {
      ...t,
      params: {
        path: {
          projectId: e
        }
      },
      parseAs: "text"
    });
  }
  /**
   * Retrieves a list of builds from the App Automate API.
   *
   * @param query - Optional query parameters for filtering the builds.
   * @param options - Optional fetch options for the API request.
   * @returns A promise that resolves to an array of automation builds.
   */
  getBuilds(e, t) {
    return this.makeGetRequest("/app-automate/builds.json", {
      ...t,
      params: {
        query: e
      }
    }).then((a) => a.map((s) => s.automation_build));
  }
  /**
   * Retrieves information about a specific build.
   * @param buildId - The ID of the build to retrieve.
   * @param options - Additional options for the fetch request.
   * @returns A promise that resolves to the build information, including the build details and associated sessions.
   */
  getBuild(e, t) {
    return this.makeGetRequest("/app-automate/builds/{buildId}.json", {
      ...t,
      params: {
        path: {
          buildId: e
        }
      }
    }).then((a) => ({
      ...a.build.automation_build,
      sessions: a.build.sessions.map(
        (s) => s.automation_session
      )
    }));
  }
  /**
   * Updates a build in the App Automate API.
   *
   * @param buildId - The ID of the build to update.
   * @param body - The request body containing the updated build information.
   * @param options - Additional options for the request.
   * @returns A Promise that resolves to the updated build.
   * @throws {BrowserStackError} If an error occurs during the update.
   */
  updateBuild(e, t, a) {
    return this.makePutRequest("/app-automate/builds/{buildId}.json", {
      ...a,
      body: t,
      params: {
        path: {
          buildId: e
        }
      }
    }).then((s) => {
      if ("error" in s)
        throw new u(s.error, { response: s });
      return s.automation_build;
    });
  }
  /**
   * Deletes a build with the specified ID.
   * @param buildId The ID of the build to delete.
   * @param options Additional options for the delete request.
   * @returns A promise that resolves when the build is successfully deleted.
   */
  deleteBuild(e, t) {
    return this.makeDeleteRequest("/app-automate/builds/{buildId}.json", {
      ...t,
      params: {
        path: {
          buildId: e
        }
      }
    });
  }
  /**
   * Uploads terminal logs for a specific build.
   * @param buildId - The ID of the build.
   * @param data - The request body containing the logs file and its filename.
   * @param options - Additional options for the request.
   * @returns A promise that resolves to the response of the request.
   */
  uploadBuildTerminalLogs(e, t, a) {
    return this.makeCloudPostRequest(
      "/app-automate/builds/{buildId}/terminallogs",
      {
        ...a,
        body: t,
        bodySerializer: (s) => {
          const p = new FormData();
          return p.append("file", s.file, t.filename), p;
        },
        params: {
          path: {
            buildId: e
          }
        }
      }
    );
  }
  /**
   * Uploads terminal logs for a session.
   * @param sessionId - The ID of the session.
   * @param data - The request body containing the logs file and filename.
   * @param options - Additional options for the request.
   * @returns A promise that resolves to the response of the request.
   */
  uploadSessionTerminalLogs(e, t, a) {
    return this.makeCloudPostRequest(
      "/app-automate/sessions/{sessionId}/terminallogs",
      {
        ...a,
        body: t,
        bodySerializer: (s) => {
          const p = new FormData();
          return p.append("file", s.file, t.filename), p;
        },
        params: {
          path: {
            sessionId: e
          }
        }
      }
    );
  }
  /**
   * Retrieves the session details for a given session ID.
   * @param sessionId - The ID of the session to retrieve.
   * @param options - Additional options for the fetch request.
   * @returns A promise that resolves to the automation session data.
   */
  getSession(e, t) {
    return this.makeGetRequest("/app-automate/sessions/{sessionId}.json", {
      ...t,
      params: {
        path: {
          sessionId: e
        }
      }
    }).then((a) => a.automation_session);
  }
  /**
   * Updates the status of a session in the App Automate API.
   *
   * @param sessionId - The ID of the session to update.
   * @param body - The request body containing the updated session status.
   * @param options - Additional options for the API request.
   * @returns A Promise that resolves to the updated automation session.
   */
  updateSessionStatus(e, t, a) {
    return this.makePutRequest("/app-automate/sessions/{sessionId}.json", {
      ...a,
      body: t,
      params: {
        path: {
          sessionId: e
        }
      }
    }).then((s) => s.automation_session);
  }
  /**
   * Deletes a session in the App Automate API.
   * @param sessionId - The ID of the session to delete.
   * @param options - Additional options for the delete request.
   * @returns A promise that resolves when the session is successfully deleted.
   */
  deleteSession(e, t) {
    return this.makeDeleteRequest("/app-automate/sessions/{sessionId}.json", {
      ...t,
      params: {
        path: {
          sessionId: e
        }
      }
    });
  }
  /**
   * Retrieves the session logs for a specific build and session.
   *
   * @param buildId - The ID of the build.
   * @param sessionId - The ID of the session.
   * @param options - Additional options for the request.
   * @returns A Promise that resolves to the session logs.
   */
  getSessionLogs(e, t, a) {
    return this.makeGetRequest(
      "/app-automate/builds/{buildId}/sessions/{sessionId}/logs",
      {
        ...a,
        params: {
          path: {
            buildId: e,
            sessionId: t
          }
        },
        parseAs: "text"
      }
    );
  }
  /**
   * Retrieves the device logs for a specific session.
   *
   * @param buildId - The ID of the build.
   * @param sessionId - The ID of the session.
   * @param options - Additional options for the request.
   * @returns A Promise that resolves with the device logs.
   */
  getSessionDeviceLogs(e, t, a) {
    return this.makeGetRequest(
      "/app-automate/builds/{buildId}/sessions/{sessionId}/devicelogs",
      {
        ...a,
        params: {
          path: {
            buildId: e,
            sessionId: t
          }
        },
        parseAs: "text"
      }
    );
  }
  /**
   * Retrieves the Appium logs for a specific session.
   *
   * @param buildId - The ID of the build.
   * @param sessionId - The ID of the session.
   * @param options - Additional options for the request.
   * @returns A Promise that resolves to the Appium logs.
   */
  getSessionAppiumLogs(e, t, a) {
    return this.makeGetRequest(
      "/app-automate/builds/{buildId}/sessions/{sessionId}/appiumlogs",
      {
        ...a,
        params: {
          path: {
            buildId: e,
            sessionId: t
          }
        },
        parseAs: "text"
      }
    );
  }
  /**
   * Retrieves the network logs for a specific session in a build.
   * @param buildId The ID of the build.
   * @param sessionId The ID of the session.
   * @param options Additional options for the network logs request.
   * @returns A Promise that resolves to the network logs response.
   */
  getSessionNetworkLogs(e, t, a) {
    return this.makeGetRequest(
      "/app-automate/builds/{buildId}/sessions/{sessionId}/networklogs",
      {
        ...a,
        params: {
          path: {
            buildId: e,
            sessionId: t
          }
        }
      }
    );
  }
  /**
   * Retrieves the app profiling data for a specific session in a build.
   * @param buildId The ID of the build.
   * @param sessionId The ID of the session.
   * @param options Additional options for the request.
   * @returns A promise that resolves to the app profiling data.
   */
  getSessionAppProfilingDataV1(e, t, a) {
    return this.makeGetRequest(
      "/app-automate/builds/{buildId}/sessions/{sessionId}/appprofiling",
      {
        ...a,
        params: {
          path: {
            buildId: e,
            sessionId: t
          }
        }
      }
    );
  }
  /**
   * Retrieves the app profiling data for a specific session in a build.
   * @param buildId The ID of the build.
   * @param sessionId The ID of the session.
   * @param options Additional options for the API request.
   * @returns A promise that resolves with the app profiling data.
   */
  getSessionAppProfilingDataV2(e, t, a) {
    return this.makeGetRequest(
      "/app-automate/builds/{buildId}/sessions/{sessionId}/appprofiling/v2",
      {
        ...a,
        params: {
          path: {
            buildId: e,
            sessionId: t
          }
        }
      }
    );
  }
  /**
   * Uploads a media file to the App Automate API.
   *
   * @param data - The request body containing the media file to upload.
   * @param options - Optional fetch options for the request.
   * @returns A promise that resolves to the response of the API request.
   */
  uploadMediaFile(e, t) {
    return this.makePostRequest("/app-automate/upload-media", {
      ...t,
      body: e,
      bodySerializer: (a) => {
        const s = new FormData();
        return s.append("file", a.file, e.filename), a.custom_id && s.append("custom_id", a.custom_id), s;
      }
    });
  }
  /**
   * Retrieves the media files associated with the App Automate session.
   *
   * @param options - Optional fetch options for the request.
   * @returns A promise that resolves to an array of media files, or an empty array if no media files are found.
   */
  getMediaFiles(e) {
    return this.makeGetRequest(
      "/app-automate/recent_media_files",
      e
    ).then((t) => "message" in t ? [] : t);
  }
  /**
   * Retrieves media files by custom ID.
   * @param customId - The custom ID to filter media files.
   * @param options - Optional fetch options.
   * @returns A promise that resolves to an array of media files or an empty array if no media files are found.
   */
  getMediaFilesByCustomId(e, t) {
    return this.makeGetRequest("/app-automate/recent_media_files/{customId}", {
      ...t,
      params: {
        path: {
          customId: e
        }
      }
    }).then((a) => "message" in a ? [] : a);
  }
  /**
   * Retrieves the group's media files from the App Automate API.
   *
   * @param options - Optional fetch options for the API request.
   * @returns A promise that resolves to an array of group media files, or an empty array if the response contains a "message" property.
   */
  getGroupMediaFiles(e) {
    return this.makeGetRequest(
      "/app-automate/recent_group_media",
      e
    ).then((t) => "message" in t ? [] : t);
  }
  /**
   * Deletes a media file from the app automate custom media.
   * @param mediaId The ID of the media file to delete.
   * @param options The fetch options for the delete request.
   * @returns A promise that resolves when the media file is successfully deleted.
   */
  deleteMediaFile(e, t) {
    return this.makeDeleteRequest(
      "/app-automate/custom_media/delete/{mediaId}",
      {
        ...t,
        params: {
          path: {
            mediaId: e
          }
        }
      }
    );
  }
  /**
   * Uploads an Appium app to BrowserStack App Automate.
   *
   * @param data - The request body containing the app file or URL to be uploaded.
   * @param options - Additional options for the request.
   * @returns A Promise that resolves to the response of the upload request.
   */
  uploadAppiumApp(e, t) {
    return this.makePostRequest("/app-automate/upload", {
      ...t,
      body: e,
      bodySerializer: (a) => {
        const s = new FormData();
        return "file" in a ? s.append("file", a.file, e.filename) : s.append("url", a.url), a.custom_id && s.append("custom_id", a.custom_id), s;
      }
    });
  }
  /**
   * Retrieves the list of Appium apps from the App Automate API.
   *
   * @param options - Optional fetch options for customizing the request.
   * @returns A promise that resolves to an array of Appium apps, or an empty array if no apps are found.
   */
  getAppiumApps(e) {
    return this.makeGetRequest("/app-automate/recent_apps", e).then(
      (t) => "message" in t ? [] : t
    );
  }
  /**
   * Retrieves the Appium apps by custom ID.
   * @param customId The custom ID of the app.
   * @param options The fetch options for the request.
   * @returns A promise that resolves to the retrieved Appium apps.
   */
  getAppiumAppsByCustomId(e, t) {
    return this.makeGetRequest("/app-automate/recent_apps/{customId}", {
      ...t,
      params: {
        path: {
          customId: e
        }
      }
    }).then((a) => "message" in a ? [] : a);
  }
  /**
   * Retrieves the list of App Automate apps for the group using the specified fetch options.
   * @param options The fetch options for the request.
   * @returns A promise that resolves to the list of group apps, or an empty array if there is a "message" property in the response data.
   */
  getAppiumGroupApps(e) {
    return this.makeGetRequest("/app-automate/recent_group_apps", e).then(
      (t) => "message" in t ? [] : t
    );
  }
  /**
   * Deletes an Appium app.
   *
   * @param appId - The ID of the app to delete.
   * @param options - Optional fetch options for the delete request.
   * @returns A promise that resolves when the app is successfully deleted.
   */
  deleteAppiumApp(e, t) {
    return this.makeDeleteRequest("/app-automate/app/delete/{appId}", {
      ...t,
      params: {
        path: {
          appId: e
        }
      }
    });
  }
  /**
   * Uploads a Flutter app for App Automate.
   *
   * @param data - The request body containing the app file or URL and other optional parameters.
   * @param options - Additional options for the request.
   * @returns A promise that resolves to the response of the request.
   */
  uploadFlutterApp(e, t, a) {
    return this.makePostRequest(
      e === "android" ? "/app-automate/flutter-integration-tests/v2/android/app" : "/app-automate/flutter-integration-tests/v2/ios/test-package",
      {
        ...a,
        body: t,
        bodySerializer: (s) => {
          const p = new FormData();
          return "file" in s ? p.append("file", s.file, t.filename) : p.append("url", s.url), s.custom_id && p.append("custom_id", s.custom_id), p;
        }
      }
    );
  }
  /**
   * Retrieves the list of Flutter apps for Android.
   *
   * @param options - The fetch options for the request.
   * @returns A promise that resolves to an array of Flutter apps, or an empty array if no apps are found.
   */
  getFlutterApps(e, t) {
    return this.makeGetRequest(
      e === "android" ? "/app-automate/flutter-integration-tests/v2/android/apps" : "/app-automate/flutter-integration-tests/v2/ios/test-packages",
      t
    ).then(
      (a) => "apps" in a ? a.apps : "test_packages" in a ? a.test_packages : []
    );
  }
  /**
   * Retrieves the Flutter app with the specified appId.
   * @param appId The ID of the Flutter app to retrieve.
   * @param options The fetch options for the request.
   * @returns A promise that resolves to the retrieved Flutter app.
   */
  getFlutterApp(e, t, a) {
    return this.makeGetRequest(
      e === "android" ? "/app-automate/flutter-integration-tests/v2/android/apps/{appId}" : "/app-automate/flutter-integration-tests/v2/ios/test-package/{appId}",
      {
        ...a,
        params: {
          path: {
            appId: t
          }
        }
      }
    ).then((s) => "app" in s ? s.app : s.test_package);
  }
  /**
   * Deletes a Flutter app from the BrowserStack App Automate service.
   * @param appId The ID of the app to delete.
   * @param options The fetch options for the delete request.
   * @returns A promise that resolves when the app is successfully deleted.
   */
  deleteFlutterApp(e, t, a) {
    return this.makeDeleteRequest(
      e === "android" ? "/app-automate/flutter-integration-tests/v2/android/apps/{appId}" : "/app-automate/flutter-integration-tests/v2/ios/test-package/{appId}",
      {
        ...a,
        params: {
          path: {
            appId: t
          }
        }
      }
    );
  }
  /**
   * Uploads an Espresso app to BrowserStack.
   *
   * @param data - The request body containing the app file or URL.
   * @param options - Additional options for the request.
   * @returns A promise that resolves to the response from the server.
   */
  uploadEspressoApp(e, t) {
    return this.makePostRequest("/app-automate/espresso/v2/app", {
      ...t,
      body: e,
      bodySerializer: (a) => {
        const s = new FormData();
        return "file" in a ? s.append("file", a.file, e.filename) : s.append("url", a.url), a.custom_id && s.append("custom_id", a.custom_id), s;
      }
    });
  }
  /**
   * Retrieves the Espresso apps from the App Automate API.
   * @param options - The fetch options for the API request.
   * @returns A promise that resolves to an array of Espresso apps.
   */
  getEspressoApps(e) {
    return this.makeGetRequest("/app-automate/espresso/v2/apps", e).then(
      (t) => "apps" in t ? t.apps : []
    );
  }
  /**
   * Retrieves the Espresso app with the specified appId.
   * @param appId The ID of the Espresso app to retrieve.
   * @param options The fetch options for the request.
   * @returns A promise that resolves to the retrieved Espresso app.
   */
  getEspressoApp(e, t) {
    return this.makeGetRequest("/app-automate/espresso/v2/apps/{appId}", {
      ...t,
      params: {
        path: {
          appId: e
        }
      }
    }).then((a) => a.app);
  }
  /**
   * Deletes an Espresso app.
   * @param appId The ID of the app to delete.
   * @param options The fetch options for the delete request.
   * @returns A promise that resolves when the app is deleted.
   */
  deleteEspressoApp(e, t) {
    return this.makeDeleteRequest("/app-automate/espresso/v2/apps/{appId}", {
      ...t,
      params: {
        path: {
          appId: e
        }
      }
    });
  }
  /**
   * Uploads an XCUITest app to BrowserStack App Automate.
   *
   * @param data - The request body containing the XCUITest app file or URL.
   * @param options - Additional options for the request.
   * @returns A Promise that resolves to the response of the request.
   */
  uploadXCUITestApp(e, t) {
    return this.makePostRequest("/app-automate/xcuitest/v2/app", {
      ...t,
      body: e,
      bodySerializer: (a) => {
        const s = new FormData();
        return "file" in a ? s.append("file", a.file, e.filename) : s.append("url", a.url), a.custom_id && s.append("custom_id", a.custom_id), s;
      }
    });
  }
  /**
   * Retrieves the XCUITest apps available in the BrowserStack App Automate.
   * @param options - The fetch options for the request.
   * @returns A promise that resolves to an array of XCUITest apps.
   */
  getXCUITestApps(e) {
    return this.makeGetRequest("/app-automate/xcuitest/v2/apps", e).then(
      (t) => "apps" in t ? t.apps : []
    );
  }
  /**
   * Retrieves the XCUITest app with the specified appId.
   * @param appId The ID of the XCUITest app to retrieve.
   * @param options The fetch options for the request.
   * @returns A promise that resolves to the XCUITest app.
   */
  getXCUITestApp(e, t) {
    return this.makeGetRequest("/app-automate/xcuitest/v2/apps/{appId}", {
      ...t,
      params: {
        path: {
          appId: e
        }
      }
    }).then((a) => a.app);
  }
  /**
   * Deletes an XCUITest app.
   * @param appId The ID of the app to delete.
   * @param options The fetch options for the delete request.
   * @returns A promise that resolves when the app is successfully deleted.
   */
  deleteXCUITestApp(e, t) {
    return this.makeDeleteRequest("/app-automate/xcuitest/v2/apps/{appId}", {
      ...t,
      params: {
        path: {
          appId: e
        }
      }
    });
  }
  /**
   * Uploads a Detox Android app or app client to the App Automate service.
   *
   * @param type - The type of the upload, either "app" or "app-client".
   * @param data - The data of the upload, including the app file and filename.
   * @param options - Optional API fetch options for the request.
   * @returns A promise that resolves to the response of the request.
   */
  uploadDetoxAndroidApp(e, t, a) {
    return this.makePostRequest(
      e ? "/app-automate/detox/v2/android/app" : "/app-automate/detox/v2/android/app-client",
      {
        ...a,
        body: t,
        bodySerializer: (s) => {
          const p = new FormData();
          return "file" in s ? p.append("file", s.file, t.filename) : p.append("url", s.url), s.custom_id && p.append("custom_id", s.custom_id), p;
        }
      }
    );
  }
}
var o = /* @__PURE__ */ ((i) => (i.android = "android", i.ios = "ios", i))(o || {});
export {
  m as A,
  o as F
};
